@@ -6,29 +6,36 @@ import org.herac.tuxguitar.android.action.impl.browser.TGBrowserAddCollectionAct
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserCdElementAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserCdRootAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserCdUpAction;
+import org.herac.tuxguitar.android.action.impl.browser.TGBrowserCloseAction;
+import org.herac.tuxguitar.android.action.impl.browser.TGBrowserCloseSessionAction;
+import org.herac.tuxguitar.android.action.impl.browser.TGBrowserLoadSessionAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserOpenElementAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserOpenSessionAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserPrepareForReadAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserPrepareForWriteAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserRefreshAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserRemoveCollectionAction;
+import org.herac.tuxguitar.android.action.impl.browser.TGBrowserRunnableAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserSaveCurrentElementAction;
 import org.herac.tuxguitar.android.action.impl.browser.TGBrowserSaveElementAction;
+import org.herac.tuxguitar.android.action.impl.browser.TGBrowserSaveNewElementAction;
 import org.herac.tuxguitar.android.action.impl.caret.TGGoDownAction;
 import org.herac.tuxguitar.android.action.impl.caret.TGGoLeftAction;
 import org.herac.tuxguitar.android.action.impl.caret.TGGoRightAction;
 import org.herac.tuxguitar.android.action.impl.caret.TGGoUpAction;
 import org.herac.tuxguitar.android.action.impl.caret.TGMoveToAction;
 import org.herac.tuxguitar.android.action.impl.caret.TGMoveToAxisPositionAction;
-import org.herac.tuxguitar.android.action.impl.edit.TGRedoAction;
 import org.herac.tuxguitar.android.action.impl.edit.TGSetVoice1Action;
 import org.herac.tuxguitar.android.action.impl.edit.TGSetVoice2Action;
-import org.herac.tuxguitar.android.action.impl.edit.TGUndoAction;
 import org.herac.tuxguitar.android.action.impl.gui.TGBackAction;
+import org.herac.tuxguitar.android.action.impl.gui.TGExitAction;
 import org.herac.tuxguitar.android.action.impl.gui.TGFinishAction;
+import org.herac.tuxguitar.android.action.impl.gui.TGOpenCabMenuAction;
 import org.herac.tuxguitar.android.action.impl.gui.TGOpenDialogAction;
 import org.herac.tuxguitar.android.action.impl.gui.TGOpenFragmentAction;
 import org.herac.tuxguitar.android.action.impl.gui.TGOpenMenuAction;
+import org.herac.tuxguitar.android.action.impl.gui.TGRequestPermissionsAction;
+import org.herac.tuxguitar.android.action.impl.gui.TGStartActivityForResultAction;
 import org.herac.tuxguitar.android.action.impl.intent.TGProcessIntentAction;
 import org.herac.tuxguitar.android.action.impl.layout.TGSetChordDiagramEnabledAction;
 import org.herac.tuxguitar.android.action.impl.layout.TGSetChordNameEnabledAction;
@@ -38,11 +45,18 @@ import org.herac.tuxguitar.android.action.impl.measure.TGGoFirstMeasureAction;
 import org.herac.tuxguitar.android.action.impl.measure.TGGoLastMeasureAction;
 import org.herac.tuxguitar.android.action.impl.measure.TGGoNextMeasureAction;
 import org.herac.tuxguitar.android.action.impl.measure.TGGoPreviousMeasureAction;
+import org.herac.tuxguitar.android.action.impl.storage.TGOpenDocumentAction;
+import org.herac.tuxguitar.android.action.impl.storage.TGSaveDocumentAction;
+import org.herac.tuxguitar.android.action.impl.storage.TGSaveDocumentAsAction;
+import org.herac.tuxguitar.android.action.impl.storage.TGStorageLoadSettingsAction;
+import org.herac.tuxguitar.android.action.impl.storage.uri.TGUriReadAction;
+import org.herac.tuxguitar.android.action.impl.storage.uri.TGUriWriteAction;
 import org.herac.tuxguitar.android.action.impl.track.TGGoFirstTrackAction;
 import org.herac.tuxguitar.android.action.impl.track.TGGoLastTrackAction;
 import org.herac.tuxguitar.android.action.impl.track.TGGoNextTrackAction;
 import org.herac.tuxguitar.android.action.impl.track.TGGoPreviousTrackAction;
 import org.herac.tuxguitar.android.action.impl.track.TGGoToTrackAction;
+import org.herac.tuxguitar.android.action.impl.transport.TGTransportLoadSettingsAction;
 import org.herac.tuxguitar.android.action.impl.transport.TGTransportPlayAction;
 import org.herac.tuxguitar.android.action.impl.transport.TGTransportStopAction;
 import org.herac.tuxguitar.android.action.impl.view.TGToggleTabKeyboardAction;
@@ -75,6 +89,8 @@ import org.herac.tuxguitar.editor.action.duration.TGSetSixteenthDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGSetSixtyFourthDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGSetThirtySecondDurationAction;
 import org.herac.tuxguitar.editor.action.duration.TGSetWholeDurationAction;
+import org.herac.tuxguitar.editor.action.edit.TGRedoAction;
+import org.herac.tuxguitar.editor.action.edit.TGUndoAction;
 import org.herac.tuxguitar.editor.action.effect.TGChangeAccentuatedNoteAction;
 import org.herac.tuxguitar.editor.action.effect.TGChangeBendNoteAction;
 import org.herac.tuxguitar.editor.action.effect.TGChangeDeadNoteAction;
@@ -104,8 +120,10 @@ import org.herac.tuxguitar.editor.action.measure.TGAddMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGAddMeasureListAction;
 import org.herac.tuxguitar.editor.action.measure.TGCleanMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGCleanMeasureListAction;
+import org.herac.tuxguitar.editor.action.measure.TGCopyMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGCopyMeasureFromAction;
 import org.herac.tuxguitar.editor.action.measure.TGInsertMeasuresAction;
+import org.herac.tuxguitar.editor.action.measure.TGPasteMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGRemoveMeasureAction;
 import org.herac.tuxguitar.editor.action.measure.TGRemoveMeasureRangeAction;
 import org.herac.tuxguitar.editor.action.note.TGChangeNoteAction;
@@ -134,6 +152,7 @@ import org.herac.tuxguitar.editor.action.song.TGCopySongFromAction;
 import org.herac.tuxguitar.editor.action.track.TGAddNewTrackAction;
 import org.herac.tuxguitar.editor.action.track.TGAddTrackAction;
 import org.herac.tuxguitar.editor.action.track.TGChangeTrackMuteAction;
+import org.herac.tuxguitar.editor.action.track.TGChangeTrackPropertiesAction;
 import org.herac.tuxguitar.editor.action.track.TGChangeTrackSoloAction;
 import org.herac.tuxguitar.editor.action.track.TGChangeTrackTuningAction;
 import org.herac.tuxguitar.editor.action.track.TGCloneTrackAction;
@@ -146,6 +165,7 @@ import org.herac.tuxguitar.editor.action.track.TGSetTrackInfoAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackMuteAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackNameAction;
 import org.herac.tuxguitar.editor.action.track.TGSetTrackSoloAction;
+import org.herac.tuxguitar.editor.action.track.TGSetTrackStringCountAction;
 import org.herac.tuxguitar.util.TGContext;
 
 public class TGActionInstaller {
@@ -205,9 +225,11 @@ public class TGActionInstaller {
 		installAction(new TGSetTrackInfoAction(context));
 		installAction(new TGSetTrackNameAction(context));
 		installAction(new TGSetTrackChannelAction(context));
+		installAction(new TGSetTrackStringCountAction(context));
 		installAction(new TGChangeTrackTuningAction(context));
 		installAction(new TGCopyTrackFromAction(context));
-		
+		installAction(new TGChangeTrackPropertiesAction(context));
+
 		//measure actions
 		installAction(new TGAddMeasureAction(context));
 		installAction(new TGAddMeasureListAction(context));
@@ -219,9 +241,10 @@ public class TGActionInstaller {
 		installAction(new TGGoPreviousMeasureAction(context));
 		installAction(new TGRemoveMeasureAction(context));
 		installAction(new TGRemoveMeasureRangeAction(context));
-		installAction(new TGCopyMeasureFromAction(context));
 		installAction(new TGInsertMeasuresAction(context));
-		
+		installAction(new TGCopyMeasureFromAction(context));
+		installAction(new TGCopyMeasureAction(context));
+		installAction(new TGPasteMeasureAction(context));
 		//beat actions
 		installAction(new TGChangeNoteAction(context));
 		installAction(new TGChangeTiedNoteAction(context));
@@ -306,6 +329,7 @@ public class TGActionInstaller {
 		//transport actions
 		installAction(new TGTransportPlayAction(context));
 		installAction(new TGTransportStopAction(context));
+		installAction(new TGTransportLoadSettingsAction(context));
 		
 		//layout actions
 		installAction(new TGSetLayoutScaleAction(context));
@@ -315,30 +339,47 @@ public class TGActionInstaller {
 		
 		//view actions
 		installAction(new TGToggleTabKeyboardAction(context));
-		
+
+		//storage
+		installAction(new TGUriReadAction(context));
+		installAction(new TGUriWriteAction(context));
+		installAction(new TGOpenDocumentAction(context));
+		installAction(new TGSaveDocumentAction(context));
+		installAction(new TGSaveDocumentAsAction(context));
+		installAction(new TGStorageLoadSettingsAction(context));
+
 		//browser actions
+		installAction(new TGBrowserCloseAction(context));
 		installAction(new TGBrowserCdRootAction(context));
 		installAction(new TGBrowserCdUpAction(context));
 		installAction(new TGBrowserCdElementAction(context));
 		installAction(new TGBrowserRefreshAction(context));
 		installAction(new TGBrowserOpenElementAction(context));
 		installAction(new TGBrowserSaveElementAction(context));
+		installAction(new TGBrowserSaveNewElementAction(context));
 		installAction(new TGBrowserSaveCurrentElementAction(context));
 		installAction(new TGBrowserPrepareForReadAction(context));
 		installAction(new TGBrowserPrepareForWriteAction(context));
+		installAction(new TGBrowserLoadSessionAction(context));
 		installAction(new TGBrowserOpenSessionAction(context));
+		installAction(new TGBrowserCloseSessionAction(context));
 		installAction(new TGBrowserAddCollectionAction(context));
 		installAction(new TGBrowserRemoveCollectionAction(context));
-		
+		installAction(new TGBrowserRunnableAction(context));
+
 		//intent actions
 		installAction(new TGProcessIntentAction(context));
 		
 		//gui actions
 		installAction(new TGBackAction(context));
+		installAction(new TGExitAction(context));
 		installAction(new TGFinishAction(context));
 		installAction(new TGOpenDialogAction(context));
 		installAction(new TGOpenMenuAction(context));
+		installAction(new TGOpenCabMenuAction(context));
 		installAction(new TGOpenFragmentAction(context));
+		installAction(new TGStartActivityForResultAction(context));
+		installAction(new TGRequestPermissionsAction(context));
 	}
 	
 	public void installAction(TGActionBase action) {
@@ -359,7 +400,7 @@ public class TGActionInstaller {
 			if( config.isLockableAction() ) {
 				this.manager.getLockableActionListener().addActionId(actionId);
 			}
-			
+
 			this.manager.getUpdatableActionListener().getControllers().set(actionId, config.getUpdateController());
 			this.manager.getUndoableActionListener().getControllers().set(actionId, config.getUndoableController());
 		}
