@@ -2,10 +2,9 @@ package org.herac.tuxguitar.graphics.control;
 
 import java.util.Iterator;
 
-import org.herac.tuxguitar.graphics.TGPainter;
-import org.herac.tuxguitar.graphics.TGRectangle;
 import org.herac.tuxguitar.graphics.control.painters.TGKeySignaturePainter;
 import org.herac.tuxguitar.graphics.control.painters.TGNotePainter;
+import org.herac.tuxguitar.graphics.control.painters.TGNumberPainter;
 import org.herac.tuxguitar.song.factory.TGFactory;
 import org.herac.tuxguitar.song.models.TGBeat;
 import org.herac.tuxguitar.song.models.TGDuration;
@@ -13,11 +12,12 @@ import org.herac.tuxguitar.song.models.TGNote;
 import org.herac.tuxguitar.song.models.TGNoteEffect;
 import org.herac.tuxguitar.song.models.TGVoice;
 import org.herac.tuxguitar.song.models.effects.TGEffectHarmonic;
+import org.herac.tuxguitar.ui.resource.UIInset;
+import org.herac.tuxguitar.ui.resource.UIPainter;
+import org.herac.tuxguitar.ui.resource.UIRectangle;
 
 public class TGNoteImpl extends TGNote {
 	
-	private TGRectangle noteOrientation;
-	
 	private float tabPosY;
 	
 	private float scorePosY;
@@ -26,31 +26,26 @@ public class TGNoteImpl extends TGNote {
 	
 	public TGNoteImpl(TGFactory factory) {
 		super(factory);
-		this.noteOrientation = new TGRectangle();
 	}
 	
-	/**
-	 * Actualiza los valores para dibujar
-	 */
 	public void update(TGLayout layout) {
 		this.accidental = getMeasureImpl().getNoteAccidental( getRealValue() );
 		this.tabPosY = ( (getString() * layout.getStringSpacing()) - layout.getStringSpacing() );
 		this.scorePosY = getVoiceImpl().getBeatGroup().getY1(layout,this,getMeasureImpl().getKeySignature(),getMeasureImpl().getClef());
 	}
 	
-	/**
-	 * Pinta la nota
-	 */
-	public void paint(TGLayout layout,TGPainter painter, float fromX, float fromY) {
+	public void paint(TGLayout layout,UIPainter painter, float fromX, float fromY) {
 		float spacing = getBeatImpl().getSpacing(layout);
+		float tabMoveX = (2f * layout.getScale());
+		
 		paintScoreNote(layout, painter, fromX, fromY + getPaintPosition(TGTrackSpacing.POSITION_SCORE_MIDDLE_LINES),spacing);
 		if(!layout.isPlayModeEnabled()){
 			paintOfflineEffects(layout, painter,fromX,fromY, spacing);
 		}
-		paintTablatureNote(layout, painter, fromX, fromY + getPaintPosition(TGTrackSpacing.POSITION_TABLATURE),spacing);
+		paintTablatureNote(layout, painter, fromX + tabMoveX, fromY + getPaintPosition(TGTrackSpacing.POSITION_TABLATURE),spacing);
 	}
 	
-	private void paintOfflineEffects(TGLayout layout,TGPainter painter,float fromX, float fromY, float spacing){		
+	private void paintOfflineEffects(TGLayout layout,UIPainter painter,float fromX, float fromY, float spacing){		
 		TGSpacing bs = getBeatImpl().getBs();
 		TGSpacing ts = getMeasureImpl().getTs();
 		TGNoteEffect effect = getEffect();
@@ -123,61 +118,123 @@ public class TGNoteImpl extends TGNote {
 		}
 	}
 	
-	/**
-	 * Pinta la nota en la tablatura
-	 */
-	public void paintTablatureNote(TGLayout layout,TGPainter painter, float fromX, float fromY, float spacing) {
+	public void paintTablatureNoteValue(TGLayout layout, UIPainter painter, UIInset margin, float fromX, float fromY, boolean running) {
+		if( layout.isTabNotePathRendererEnabled() ) {
+			this.paintTablatureNoteValuePathMode(layout, painter, margin, fromX, fromY, running);
+		} else {
+			this.paintTablatureNoteValueTextMode(layout, painter, margin, fromX, fromY, running);
+		}
+	}
+	
+	public void paintTablatureNoteValuePathMode(TGLayout layout, UIPainter painter, UIInset margin, float fromX, float fromY, boolean running) {
+		float noteSize = (layout.getStringSpacing() - 2f);
+		float noteWidth = (this.getEffect().isDeadNote() ? 6f * layout.getScale() : TGNumberPainter.getDigitsWidth(getValue(), noteSize));
+		float ghostWidth = (this.getEffect().isGhostNote() ? 3f * layout.getScale() : 0f);
+		
+		margin.setTop(noteSize / 2f);
+		margin.setBottom(noteSize / 2f);
+		margin.setLeft((noteWidth / 2f) + ghostWidth);
+		margin.setRight((noteWidth / 2f) + ghostWidth);
+		
+		this.fillBackground(layout, painter, margin, fromX, fromY);
+		layout.setTabNotePathStyle(painter, running);
+		if( this.getEffect().isDeadNote() ) {
+			painter.initPath(UIPainter.PATH_DRAW);
+			painter.moveTo(fromX - (margin.getLeft() - ghostWidth), fromY - margin.getTop());
+			painter.lineTo(fromX + (margin.getRight() - ghostWidth), fromY + margin.getBottom());
+			painter.moveTo(fromX + (margin.getRight() - ghostWidth), fromY - margin.getTop());
+			painter.lineTo(fromX - (margin.getLeft() - ghostWidth), fromY + margin.getBottom());
+			
+			painter.closePath();
+		} else {
+			TGNumberPainter.paintDigits(getValue(), painter, fromX - (margin.getLeft() - ghostWidth), fromY - margin.getTop(), noteSize);
+		}
+		
+		if( this.getEffect().isGhostNote() ) {
+			float ghostLineWidth = (2f * layout.getScale());
+			float ghostY1 = fromY - margin.getTop();
+			float ghostY2 = fromY + margin.getBottom();
+			float ghostLeftX1 = fromX - (margin.getLeft() - ghostWidth);
+			float ghostLeftX2 = fromX - margin.getLeft();
+			float ghostRightX1 = fromX + (margin.getRight() - ghostWidth);
+			float ghostRightX2 = fromX + margin.getRight();
+			
+			painter.initPath(UIPainter.PATH_FILL);
+			painter.moveTo(ghostLeftX1, ghostY1);
+			painter.cubicTo(ghostLeftX2 - ghostLineWidth, ghostY1, ghostLeftX2 - ghostLineWidth, ghostY2, ghostLeftX1, ghostY2);
+			painter.cubicTo(ghostLeftX2, ghostY2, ghostLeftX2, ghostY1, ghostLeftX1, ghostY1);
+			painter.closePath();
+			
+			painter.initPath(UIPainter.PATH_FILL);
+			painter.moveTo(ghostRightX1, ghostY1);
+			painter.cubicTo(ghostRightX2 + ghostLineWidth, ghostY1, ghostRightX2 + ghostLineWidth, ghostY2, ghostRightX1, ghostY2);
+			painter.cubicTo(ghostRightX2, ghostY2, ghostRightX2, ghostY1, ghostRightX1, ghostY1);
+			painter.closePath();
+		}
+	}
+	
+	public void paintTablatureNoteValueTextMode(TGLayout layout, UIPainter painter, UIInset margin, float fromX, float fromY, boolean running) {
+		layout.setTabNoteFontStyle(painter, running);
+		
+		String label = this.getNoteLabel(this);
+		float fmWidth = painter.getFMWidth(label);
+		float fmTopLine = painter.getFMTopLine();
+		float fmMiddleLine = painter.getFMMiddleLine();
+		float fmBaseLine = painter.getFMBaseLine();
+		
+		margin.setTop((fmTopLine - fmBaseLine) / 2);
+		margin.setBottom((fmTopLine - fmBaseLine) / 2);
+		margin.setLeft(fmWidth / 2);
+		margin.setRight(fmWidth / 2);
+		
+		this.fillBackground(layout, painter, margin, fromX, fromY);
+		layout.setTabNoteFontStyle(painter, running);
+		painter.drawString(label, fromX - margin.getLeft(), fromY + fmMiddleLine);
+	}
+	
+	public void paintTablatureNote(TGLayout layout,UIPainter painter, float fromX, float fromY, float spacing) {
 		int style = layout.getStyle();
-		if((style & TGLayout.DISPLAY_TABLATURE) != 0){
+		if((style & TGLayout.DISPLAY_TABLATURE) != 0) {
+			UIInset margin = new UIInset();
+			
 			float scale = layout.getScale();
-			float xMove = (2 * scale);
-			float x = (fromX + getPosX() + spacing + xMove);
+			float x = (fromX + getPosX() + spacing);
 			float y = (fromY + getTabPosY());
 			float stringSpacing = layout.getStringSpacing();
 			
-			this.noteOrientation.setX(Math.round(x));
-			this.noteOrientation.setY(Math.round(y));
-			this.noteOrientation.setWidth(1);
-			this.noteOrientation.setHeight(1);
+			boolean running = (layout.isPlayModeEnabled() && getBeatImpl().isPlaying(layout));
 			
-			layout.setTabNoteStyle(painter, (layout.isPlayModeEnabled() && getBeatImpl().isPlaying(layout)));
 			//-------------ligadura--------------------------------------
 			if (isTiedNote() && (style & TGLayout.DISPLAY_SCORE) == 0) {
 				float tX = 0;
-				float tY = 0;
-				float tWidth = 0;
-				float tHeight = (stringSpacing * 3);
+				float tY = (fromY + getTabPosY() + (stringSpacing / 2f));
 				TGNoteImpl noteForTie = getNoteForTie();
 				if (noteForTie != null) {
-					tX = (fromX + noteForTie.getPosX() + noteForTie.getBeatImpl().getSpacing(layout));
-					tY = (fromY + noteForTie.getTabPosY() + stringSpacing);
-					tWidth = (x - tX);
+					tX = (fromX + noteForTie.getPosX() + noteForTie.getBeatImpl().getSpacing(layout) + (5.0f * scale));
 				}else{
-					TGRectangle r = layout.getNoteOrientation(painter, x, y, this);
-					tX = r.getX() - (stringSpacing * 2);
-					tY = (fromY + getTabPosY() + stringSpacing);
-					tWidth = (stringSpacing * 2);
+					tX = (fromX + this.getPosX() + this.getBeatImpl().getSpacing(layout) - (stringSpacing * 2));
 				}
-				painter.initPath();
-				painter.addArc(tX, (tY - tHeight ), tWidth, tHeight, 225, 90);
+				
+				float tWidth = (x - tX);
+				float tHeight1 = (stringSpacing / 3f);
+				float tHeight2 = (tHeight1 + (scale * 2f));
+				
+				layout.setTabTiedStyle(painter, running);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.moveTo(tX, tY);
+				painter.cubicTo(tX, tY + tHeight1, tX + tWidth, tY + tHeight1, tX + tWidth, tY);
+				painter.cubicTo(tX + tWidth, tY + tHeight2, tX, tY + tHeight2, tX, tY);
 				painter.closePath();
 				
 			//-------------nota--------------------------------------
-			} else if(!isTiedNote()){
-				TGRectangle r = layout.getNoteOrientation(painter, x, y, this);
-				this.noteOrientation.setX(r.getX());
-				this.noteOrientation.setY(r.getY());
-				this.noteOrientation.setWidth(r.getWidth());
-				this.noteOrientation.setHeight(r.getHeight());
-				String visualNote = (getEffect().isDeadNote()) ? "X" : Integer.toString(getValue());
-				visualNote = (getEffect().isGhostNote()) ? "(" + visualNote + ")" : visualNote;
-				painter.drawString(visualNote, this.noteOrientation.getX(), this.noteOrientation.getY());
+			} else if(!isTiedNote()) {
+				this.paintTablatureNoteValue(layout, painter, margin, x, y, running);
 			}
 			
 			//-------------efectos--------------------------------------
 			if(! layout.isPlayModeEnabled() ){
 				
-				paintEffects(layout,painter,fromX,fromY,spacing);
+				paintEffects(layout, painter, margin, fromX, fromY, spacing);
 				
 				if((style & TGLayout.DISPLAY_SCORE) == 0){
 					
@@ -187,7 +244,7 @@ public class TGNoteImpl extends TGNote {
 						float y2 = (fromY + getMeasureImpl().getTrackImpl().getTabHeight() + ((stringSpacing / 2) * 5));
 						
 						layout.setTabEffectStyle(painter);
-						painter.setLineWidth(2f * scale);
+						painter.setLineWidth(layout.getLineWidth(2));
 						painter.initPath();
 						float posy = (y1 + ((y2 - y1) / 2));
 						for(int i = TGDuration.EIGHTH;i <= getEffect().getTremoloPicking().getDuration().getValue(); i += i){
@@ -196,17 +253,14 @@ public class TGNoteImpl extends TGNote {
 							posy += (4f * scale);
 						}
 						painter.closePath();
-						painter.setLineWidth(1f * scale);
+						painter.setLineWidth(layout.getLineWidth(1));
 					}
 				}
 			}
 		}
 	}
 	
-	/**
-	 * Pinta la nota en la partitura
-	 */
-	private void paintScoreNote(TGLayout layout,TGPainter painter, float fromX, float fromY, float spacing) {
+	private void paintScoreNote(TGLayout layout,UIPainter painter, float fromX, float fromY, float spacing) {
 		if((layout.getStyle() & TGLayout.DISPLAY_SCORE) != 0 ){
 			float scale = layout.getScoreLineSpacing();
 			float layoutScale = layout.getScale();
@@ -222,48 +276,55 @@ public class TGNoteImpl extends TGNote {
 			//-------------foreground--------------------------------------
 			boolean playing = (layout.isPlayModeEnabled() && getBeatImpl().isPlaying(layout));
 			
-			layout.setScoreNoteStyle(painter,playing);
-			
 			//----------ligadura---------------------------------------
 			if (isTiedNote()) {
 				TGNoteImpl noteForTie = getNoteForTie();
 				float tX = x - (20.0f * layoutScale);
-				float tY = y1 - (2.0f * layoutScale);
-				float tWidth = (20.0f * layoutScale);
-				float tHeight = (30.0f * layoutScale);
+				float tY = (y1 + (layout.getScoreLineSpacing() / 2f));
 				if (noteForTie != null) {
 					float tNoteX = (fromX + noteForTie.getPosX() + noteForTie.getBeatImpl().getSpacing(layout));
 					float tNoteY = (fromY + getScorePosY());
-					tX = tNoteX + (6.0f * layoutScale);
-					tY = tNoteY - (3.0f * layoutScale);
-					tWidth = (x - tNoteX) - (3.0f * layoutScale);
-					tHeight = (35.0f * layoutScale);
+					tX = tNoteX + (10.0f * layoutScale);
+					tY = (tNoteY + (layout.getScoreLineSpacing() / 2f));
 				}
-				painter.initPath();
-				painter.addArc(tX,tY, tWidth, tHeight, 45, 90);
+				float tWidth = (x - tX) - (3.0f * layoutScale);
+				float tHeight1 = (layout.getScoreLineSpacing() / 2f);
+				float tHeight2 = (tHeight1 - (layoutScale * 2f));
+				
+				layout.setTiedStyle(painter, playing);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.moveTo(tX, tY);
+				painter.cubicTo(tX, tY - tHeight1, tX + tWidth, tY - tHeight1, tX + tWidth, tY);
+				painter.cubicTo(tX + tWidth, tY - tHeight2, tX, tY - tHeight2, tX, tY);
 				painter.closePath();
 			}
+			
+			layout.setScoreNoteStyle(painter,playing);
+			
 			//----------sostenido--------------------------------------
 			if(this.accidental == TGMeasureImpl.NATURAL){
-				painter.initPath(TGPainter.PATH_FILL);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.setLineWidth(layout.getLineWidth(0));
 				TGKeySignaturePainter.paintNatural(painter,(x - (scale - (scale / 4)) ),(y1 + (scale / 2)), scale);
 				painter.closePath();
 			}
 			else if(this.accidental == TGMeasureImpl.SHARP){
-				painter.initPath(TGPainter.PATH_FILL);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.setLineWidth(layout.getLineWidth(0));
 				TGKeySignaturePainter.paintSharp(painter,(x - (scale - (scale / 4)) ),(y1 + (scale / 2)), scale);
 				painter.closePath();
 			}
 			else if(this.accidental == TGMeasureImpl.FLAT){
-				painter.initPath(TGPainter.PATH_FILL);
+				painter.initPath(UIPainter.PATH_FILL);
+				painter.setLineWidth(layout.getLineWidth(0));
 				TGKeySignaturePainter.paintFlat(painter,(x - (scale - (scale / 4)) ),(y1 + (scale / 2)), scale);
 				painter.closePath();
 			}
 			//----------fin sostenido--------------------------------------
 			if(getEffect().isHarmonic()){
 				boolean fill = (getVoice().getDuration().getValue() >= TGDuration.QUARTER);
-				painter.setLineWidth(1f * layoutScale);
-				painter.initPath((fill ? (TGPainter.PATH_FILL | TGPainter.PATH_DRAW) : TGPainter.PATH_DRAW));
+				painter.setLineWidth(layout.getLineWidth(1));
+				painter.initPath((fill ? (UIPainter.PATH_FILL | UIPainter.PATH_DRAW) : UIPainter.PATH_DRAW));
 				TGNotePainter.paintHarmonic(painter, x, y1 + (1f * (scale / 10f)), (layout.getScoreLineSpacing() - ((scale / 10f) * 2f)));
 				painter.closePath();
 			}else{
@@ -272,8 +333,8 @@ public class TGNoteImpl extends TGNote {
 				float noteY = (fill ? (y1 + (0.60f * (scale / 10f))) : (y1 + (1f * (scale / 10f))));
 				float noteScale = (fill ? ((layout.getScoreLineSpacing() - ((scale / 10f) * 1f) )) : ((layout.getScoreLineSpacing() - ((scale / 10f) * 2f) )));
 				
-				painter.setLineWidth(1f * layoutScale);
-				painter.initPath((fill ? TGPainter.PATH_FILL : TGPainter.PATH_DRAW));
+				painter.setLineWidth(layout.getLineWidth(1));
+				painter.initPath((fill ? UIPainter.PATH_FILL : UIPainter.PATH_DRAW));
 				TGNotePainter.paintNote(painter, noteX, noteY, noteScale);
 				painter.closePath();
 			}
@@ -302,15 +363,16 @@ public class TGNoteImpl extends TGNote {
 						float sX = x + xMove;
 						float sY = (y2 + ((4f * layoutScale) * ((direction == TGBeatGroup.DIRECTION_UP) ? -1 : 1 )));
 						layout.setScoreEffectStyle(painter);
-						painter.initPath(TGPainter.PATH_FILL);
-						painter.moveTo(sX - (size / 2),sY - (size / 2));
-						painter.addOval(sX - (size / 2),sY - (size / 2), size, size);
+						painter.setLineWidth(layout.getLineWidth(1));
+						painter.initPath(UIPainter.PATH_FILL);
+						painter.moveTo(sX, sY);
+						painter.addCircle(sX, sY, size);
 						painter.closePath();
 					}
 					//tremolo picking
 					if(getEffect().isTremoloPicking()){
 						layout.setScoreEffectStyle(painter);
-						painter.setLineWidth(2f * layoutScale);
+						painter.setLineWidth(layout.getLineWidth(2));
 						painter.initPath();
 						float tpY = fromY;
 						if((direction == TGBeatGroup.DIRECTION_UP)){
@@ -324,7 +386,7 @@ public class TGNoteImpl extends TGNote {
 							tpY += (4f * layoutScale);
 						}
 						painter.closePath();
-						painter.setLineWidth(1f * layoutScale);
+						painter.setLineWidth(layout.getLineWidth(1));
 					}
 				}else{
 					
@@ -334,14 +396,16 @@ public class TGNoteImpl extends TGNote {
 						float sX = (x + (scoreNoteWidth / 2));
 						float sY = (fromY + getVoiceImpl().getBeatGroup().getMinNote().getScorePosY() + layout.getScoreLineSpacing()) + (2f * layoutScale);
 						layout.setScoreEffectStyle(painter);
-						painter.initPath(TGPainter.PATH_FILL);
-						painter.moveTo(sX - (size / 2), sY - (size / 2));
-						painter.addOval(sX - (size / 2), sY - (size / 2), size, size);
+						painter.setLineWidth(layout.getLineWidth(1));
+						painter.initPath(UIPainter.PATH_FILL);
+						painter.moveTo(sX, sY);
+						painter.addCircle(sX, sY, size);
 						painter.closePath();
 					}
 					//tremolo picking
 					if(getEffect().isTremoloPicking()){
 						layout.setScoreEffectStyle(painter);
+						painter.setLineWidth(layout.getLineWidth(2));
 						painter.initPath();
 						float tpX = ((x + (scoreNoteWidth / 2)));
 						float tpY = (fromY + (getVoiceImpl().getBeatGroup().getMaxNote().getScorePosY() - layout.getScoreLineSpacing() - (4f  * layoutScale)));
@@ -350,18 +414,14 @@ public class TGNoteImpl extends TGNote {
 							painter.lineTo(tpX + (4f * layoutScale),tpY - (1f * layoutScale));
 							tpY += (4f * layoutScale);
 						}
-						painter.setLineWidth(2f * layoutScale);
 						painter.closePath();
-						painter.setLineWidth(1f * layoutScale);
+						painter.setLineWidth(layout.getLineWidth(1));
 					}
 				}
 			}
 		}
 	}
 	
-	/**
-	 * Encuentra la nota a la que esta ligada
-	 */
 	private TGNoteImpl getNoteForTie() {
 		for (int i = getMeasureImpl().countBeats() - 1; i >= 0; i--) {
 			TGBeat beat = getMeasureImpl().getBeat(i);
@@ -379,22 +439,19 @@ public class TGNoteImpl extends TGNote {
 		return null;
 	}
 	
-	/**
-	 * Pinta los efectos
-	 */
-	private void paintEffects(TGLayout layout,TGPainter painter, float fromX, float fromY, float spacing){
+	private void paintEffects(TGLayout layout,UIPainter painter, UIInset margin, float fromX, float fromY, float spacing){
 		float x = fromX + getPosX() + spacing;
 		float y = fromY + getTabPosY();
 		TGNoteEffect effect = getEffect();
 		if(effect.isGrace()){
 			layout.setTabGraceStyle(painter);
 			String value = Integer.toString(effect.getGrace().getFret());
-			painter.drawString(value, (this.noteOrientation.getX() - painter.getFMWidth(value) - 2), this.noteOrientation.getY() );
+			painter.drawString(value, (x - margin.getLeft() - painter.getFMWidth(value)), y + painter.getFMMiddleLine());
 		}
 		if(effect.isBend()){
-			paintBend(layout, painter,(this.noteOrientation.getX() + this.noteOrientation.getWidth()), y);
+			paintBend(layout, painter, (x + margin.getRight()), y);
 		}else if(effect.isTremoloBar()){
-			paintTremoloBar(layout, painter,(this.noteOrientation.getX() + this.noteOrientation.getWidth()), y);
+			paintTremoloBar(layout, painter, (x + margin.getRight()), y);
 		}else if(effect.isSlide() || effect.isHammer()){
 			float nextFromX = fromX;
 			TGNoteImpl nextNote = (TGNoteImpl)layout.getSongManager().getMeasureManager().getNextNote(getMeasureImpl(),getBeatImpl().getStart(),getVoice().getIndex(),getString());
@@ -406,13 +463,13 @@ public class TGNoteImpl extends TGNote {
 		}
 	}
 	
-	private void paintBend(TGLayout layout,TGPainter painter,float fromX,float fromY){
+	private void paintBend(TGLayout layout,UIPainter painter,float fromX,float fromY){
 		float scale = layout.getScale();
 		float x = (fromX + (1.0f * scale));
 		float y = (fromY - (2.0f * scale));
 		
 		layout.setTabEffectStyle(painter);
-		
+		painter.setLineWidth(layout.getLineWidth(1));
 		painter.initPath();
 		painter.moveTo( x, y );
 		painter.lineTo( x + (1.0f * scale), y );
@@ -426,13 +483,14 @@ public class TGNoteImpl extends TGNote {
 		painter.closePath();
 	}
 	
-	private void paintTremoloBar(TGLayout layout,TGPainter painter,float fromX,float fromY){
+	private void paintTremoloBar(TGLayout layout,UIPainter painter,float fromX,float fromY){
 		float scale = layout.getScale();
 		float x1 = fromX + (1.0f * scale);
 		float x2 = x1 + (8.0f * scale);
 		float y1 = fromY;
 		float y2 = y1 + (9.0f * scale);
 		layout.setTabEffectStyle(painter);
+		painter.setLineWidth(layout.getLineWidth(1));
 		painter.initPath();
 		painter.moveTo(x1,y1);
 		painter.lineTo(x1 + ( (x2 - x1) / 2 ),y2);
@@ -441,13 +499,14 @@ public class TGNoteImpl extends TGNote {
 		painter.closePath();
 	}
 	
-	private void paintSlide(TGLayout layout,TGPainter painter,TGNoteImpl nextNote,float fromX,float fromY,float nextFromX){
+	private void paintSlide(TGLayout layout,UIPainter painter,TGNoteImpl nextNote,float fromX,float fromY,float nextFromX){
 		float xScale = layout.getScale();
 		float yScale = (layout.getStringSpacing() / 10.0f);
 		float yMove = (3.0f * yScale);
 		float x = fromX;
 		float y = fromY;
 		layout.setTabEffectStyle(painter);
+		painter.setLineWidth(layout.getLineWidth(1));
 		if(nextNote != null){
 			float nextX = nextNote.getPosX() + nextFromX + nextNote.getBeatImpl().getSpacing(layout);
 			float nextY = y;
@@ -463,40 +522,44 @@ public class TGNoteImpl extends TGNote {
 				nextY -= yMove;
 			}
 			painter.initPath();
-			painter.moveTo(x + (6.0f * xScale),y);
-			painter.lineTo(nextX - (3.0f * xScale),nextY);
+			painter.moveTo(x + (5f * xScale), y);
+			painter.lineTo(nextX - (5f * xScale), nextY);
 			painter.closePath();
 		}else{
 			painter.initPath();
-			painter.moveTo(x + (6.0f * xScale),y - yMove);
-			painter.lineTo(x + (17.0f * xScale),y - yMove);
+			painter.moveTo(x + (5f * xScale), y - yMove);
+			painter.lineTo(x + (18f * xScale), y - yMove);
 			painter.closePath();
 		}
 	}
 	
-	private void paintHammer(TGLayout layout, TGPainter painter, TGNoteImpl nextNote, float fromX, float fromY,float nextFromX){
-		float xScale = layout.getScale();
-		float yScale = (layout.getStringSpacing() / 10.0f);
+	private void paintHammer(TGLayout layout, UIPainter painter, TGNoteImpl nextNote, float fromX, float fromY,float nextFromX){
+		float scale = layout.getScale();
+		float x = (fromX + (5.0f * scale));
+		float y = fromY;
 		
-		float x = (fromX + (7.0f * xScale));
-		float y = (fromY - (5.0f * yScale));
+		float width = (nextNote != null ? ((nextNote.getPosX() + nextFromX + nextNote.getBeatImpl().getSpacing(layout)) - (5f * scale) - x) : (10f * scale));
+		float height1 = (layout.getStringSpacing() / 2f);
+		float height2 = (height1 - (scale * 2f));
 		
-		float width = (nextNote != null)?( (nextNote.getPosX() + nextFromX + nextNote.getBeatImpl().getSpacing(layout)) - (4.0f * xScale) - x ):(10.0f * xScale);
-		float height = (15.0f * yScale);
 		layout.setTabEffectStyle(painter);
-		painter.initPath();
-		painter.addArc(x,y, width, height, 45,90);
+		painter.setLineWidth(layout.getLineWidth(1));
+		painter.initPath(UIPainter.PATH_FILL);
+		painter.moveTo(x, y);
+		painter.cubicTo(x, y - height1, x + width, y - height1, x + width, y);
+		painter.cubicTo(x + width, y - height2, x, y - height2, x, y);
 		painter.closePath();
 	}
 	
-	private void paintGrace(TGLayout layout, TGPainter painter,float fromX,float fromY){
-		float scale = ( layout.getScoreLineSpacing() / 2.25f );
+	private void paintGrace(TGLayout layout, UIPainter painter,float fromX,float fromY){
+		float scale = (layout.getScoreLineSpacing() / 2.25f);
 		
 		float x = fromX - (2f * scale);
 		float y = fromY + (scale / 3);
 		
 		layout.setScoreEffectStyle(painter);
-		painter.initPath(TGPainter.PATH_FILL);
+		painter.setLineWidth(layout.getLineWidth(1));
+		painter.initPath(UIPainter.PATH_FILL);
 		TGNotePainter.paintFooter(painter,x, y , -1 , scale);
 		painter.closePath();
 		
@@ -505,8 +568,8 @@ public class TGNoteImpl extends TGNote {
 		painter.lineTo(x, y + (2f * scale) - (scale / 4f));
 		painter.closePath();
 		
-		painter.initPath(TGPainter.PATH_DRAW | TGPainter.PATH_FILL);
-		TGNotePainter.paintNote(painter,x - scale*1.33f, y + scale + (scale / 4f),  scale);
+		painter.initPath(UIPainter.PATH_DRAW | UIPainter.PATH_FILL);
+		TGNotePainter.paintNote(painter, x - scale * 1.33f, y + scale + (scale / 4f),  scale);
 		painter.closePath();
 		
 		painter.initPath();
@@ -515,7 +578,7 @@ public class TGNoteImpl extends TGNote {
 		painter.closePath();
 	}
 	
-	private void paintVibrato(TGLayout layout, TGPainter painter,float fromX,float fromY){
+	private void paintVibrato(TGLayout layout, UIPainter painter,float fromX,float fromY){
 		float scale = layout.getScale();
 		float x = fromX;
 		float y = fromY + (2.0f * scale);
@@ -524,7 +587,8 @@ public class TGNoteImpl extends TGNote {
 		int loops = Math.round(width / (6.0f * scale) );
 		if( loops > 0 ){
 			layout.setTabEffectStyle(painter);
-			painter.initPath(TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(1));
+			painter.initPath(UIPainter.PATH_FILL);
 			painter.moveTo(( x + ((2.0f) * scale) ),( y + (1.0f * scale) ));
 			for( int i = 0; i < loops ; i ++ ){
 				x = (fromX + ( (6.0f * scale) * i ) );
@@ -549,7 +613,7 @@ public class TGNoteImpl extends TGNote {
 		}
 	}
 	
-	private void paintTrill(TGLayout layout, TGPainter painter,float fromX,float fromY){
+	private void paintTrill(TGLayout layout, UIPainter painter,float fromX,float fromY){
 		String string = "Tr";
 		float fmWidth = painter.getFMWidth( string );
 		float scale = layout.getScale();
@@ -563,7 +627,8 @@ public class TGNoteImpl extends TGNote {
 			painter.drawString(string, fromX, textY);
 			
 			layout.setTabEffectStyle(painter);
-			painter.initPath(TGPainter.PATH_FILL);
+			painter.setLineWidth(layout.getLineWidth(1));
+			painter.initPath(UIPainter.PATH_FILL);
 			painter.moveTo(( x + (2.0f * scale) ),( y + (1.0f * scale) ));
 			for( int i = 0; i < loops ; i ++ ){
 				x = (fromX + fmWidth + ( (6.0f * scale) * i ) );
@@ -588,11 +653,12 @@ public class TGNoteImpl extends TGNote {
 		}
 	}
 	
-	private void paintFadeIn(TGLayout layout, TGPainter painter,float fromX,float fromY){
+	private void paintFadeIn(TGLayout layout, UIPainter painter,float fromX,float fromY){
 		float scale = layout.getScale();
 		float x = fromX;
 		float y = fromY + (4.0f * scale );
 		float width = getVoiceImpl().getWidth();
+		painter.setLineWidth(layout.getLineWidth(1));
 		painter.initPath();
 		painter.moveTo ( x , y );
 		painter.cubicTo( x , y , x + width, y,  x + width, y - (4.0f * scale ));
@@ -602,10 +668,11 @@ public class TGNoteImpl extends TGNote {
 		painter.closePath();
 	}
 	
-	private void paintAccentuated(TGLayout layout, TGPainter painter,float fromX,float fromY){
+	private void paintAccentuated(TGLayout layout, UIPainter painter,float fromX,float fromY){
 		float scale = layout.getScale();
 		float x = fromX;
 		float y = fromY + (2f * scale );
+		painter.setLineWidth(layout.getLineWidth(1));
 		painter.initPath();
 		painter.moveTo( x , y );
 		painter.lineTo( x + (6.0f * scale ) , y + (2.5f * scale ));
@@ -614,10 +681,11 @@ public class TGNoteImpl extends TGNote {
 		painter.closePath();
 	}
 	
-	private void paintHeavyAccentuated(TGLayout layout, TGPainter painter,float fromX,float fromY){
+	private void paintHeavyAccentuated(TGLayout layout, UIPainter painter,float fromX,float fromY){
 		float scale = layout.getScale();
 		float x = fromX;
 		float y = fromY;
+		painter.setLineWidth(layout.getLineWidth(1));
 		painter.initPath();
 		painter.moveTo( x , y + (5.0f * scale ) );
 		painter.lineTo( x + (3.0f * scale ) , y + (1.0f * scale ));
@@ -626,6 +694,28 @@ public class TGNoteImpl extends TGNote {
 		painter.closePath();
 	}
 	
+	public void fillBackground(TGLayout layout, UIPainter painter, UIInset margin, float fromX, float fromY) {
+		UIRectangle uiRectangle = new UIRectangle();
+		uiRectangle.getPosition().setX(fromX - margin.getLeft());
+		uiRectangle.getPosition().setY(fromY - margin.getTop());
+		uiRectangle.getSize().setWidth(margin.getLeft() + margin.getRight());
+		uiRectangle.getSize().setHeight(margin.getTop() + margin.getBottom());
+		
+		layout.fillBackground(painter, uiRectangle);
+	}
+	
+	public String getNoteLabel(TGNote note) {
+		String label = null;
+		if( note.isTiedNote()) {
+			label = "L";
+		} else if(note.getEffect().isDeadNote()) {
+			label = "X";
+		} else {
+			label = Integer.toString(note.getValue());
+		}
+		return (note.getEffect().isGhostNote() ? "(" + label + ")" : label);
+	}
+	
 	public int getRealValue(){
 		return (getValue() + getMeasureImpl().getTrack().getString(getString()).getValue());
 	}
